drop database glarimy;
go
create database glarimy;
go
use glarimy;
go
create table address(
	id int primary key identity(1,1),
	location varchar(32),
	city varchar(32) not null,
	pin int not null,
	phone bigint not null
);

create table branch(
	code int primary key identity(1,1),
	name varchar(32) not null unique,
	address_id int references address(id)
);

create table customer(
	id int primary key identity(22071972,1),
	first_name varchar(16) not null,
	last_name varchar(16) not null,
	dob date not null,
	address_id int references address(id),
	branch_code int references branch(code)
);

create table debitcard(
	number bigint primary key identity(1234567899876543, 1),
	pin int not null,
	cvc int not null,
	from_date date not null default sysdatetime(),
	expiry_date date not null,
	check(expiry_date > from_date)
);

create table account(
	number int primary key identity(23101987,1),
	type varchar(8) not null default 'SB' check(type in ('SB','CA')),
	status varchar(8) not null default 'active' check(status in ('active','suspended','closed')),
	debitcard_number bigint references debitcard(number),
	customer_id int references customer(id)
);

create table credentials(
	id int primary key identity(1,1),
	uname varchar(8) not null,
	pwd varchar(8) not null,
	customer_id int references customer(id),
	account_number int references account(number)
);

create table requests(
	id int primary key identity(1,1),
	date_open date not null default sysdatetime() check (date_open <= sysdatetime()),
	date_close date check (date_close <= sysdatetime()),
	description varchar(64) not null,
	owner varchar(32),
	status varchar(8) not null default 'open' check(status in ('open', 'closed')),
	customer_id int references customer(id),
	check (date_close = null or date_close>date_open)
);

create table transactions(
	id int primary key identity(1,1),
	date date not null default sysdatetime() check (date <= sysdatetime()),
	amount decimal(8,2) not null check(amount > 0),
	type varchar(8) not null default 'CR' check(type in ('CR', 'DB')),
	balance decimal(8,2) not null,
	remarks varchar(32) not null,
	account_number int references account(number)
);

create table current_account(
	id int primary key identity(1,1),
	company varchar(32) not null,
	account_number int references account(number)
);

insert into address(location, city, pin, phone) values('Pai Layout', 'Bangalore', 560016, 9731423166);
insert into address(location, city, pin, phone) values('Old Madras Road', 'Bangalore', 560034, 08040958097);
insert into branch (name, address_id) values ('Banniganihalli', 2);
insert into customer (first_name, last_name, dob, address_id, branch_code) values ('Krishna Mohan', 'Koyya', '07/22/1972', 1, 1);
insert into customer (first_name, last_name, dob, address_id, branch_code) values ('Surekha', 'A', '08/30/1987', 1, 1);
insert into debitcard(pin, cvc, from_date, expiry_date) values (225295, 919, '01/01/2012', '01/01/2015');
insert into debitcard(pin, cvc, from_date, expiry_date) values (231087, 134, '01/01/2012', '01/01/2015');
insert into debitcard(pin, cvc, from_date, expiry_date) values (260707, 629, '01/01/2012', '01/01/2015');
insert into account(debitcard_number, customer_id) values (1234567899876543, 22071972);
insert into account(type, debitcard_number, customer_id) values ('CA', 1234567899876544, 22071972);
insert into account(debitcard_number, customer_id) values (1234567899876545, 22071973);
insert into credentials(uname, pwd, customer_id, account_number) values ('koyya', 'india', 22071972, 23101987);
insert into credentials(uname, pwd, customer_id, account_number) values ('kim', 'india', 22071972, 23101988);
insert into credentials(uname, pwd, customer_id, account_number) values ('suri', 'india', 22071973, 23101989);
insert into requests (description, customer_id) values ('Change the password', 22071973);
insert into transactions (amount, balance, remarks, account_number) values (500, 500, 'Initial Deposite', 23101988);
insert into transactions (amount, balance, remarks, account_number) values (1500, 2000, 'Invoice cleared', 23101988);
insert into transactions (amount, balance, remarks, account_number) values (200, 2200, 'Interest earned', 23101988);
insert into current_account (company, account_number) values ('Glarimy', 23101988);