/*
 ********** SIMPLETE DDL with Constraints *******************
*/
/*
 * Drop the table if it already exists
 */
if object_id('expenditure', 'U') is not null
	drop table expenditure;

/*
 * Create a table to store data related to personal expenses, with the the following features:
 * 1. The primary key, a surrogate key, should be incrementable automatically starting from 1 in steps of 1
 * 2. The date of spending must not be null and not be beyond the current day
 * 3. The item must be recorded and it must not be 'pirated'
 * 4. The amount must be within the range of 0 (excluding) and 1000.
 * 5. The mode of payment must be cash, cheque, creditcard or debitcard.
 * 6. The instrument number & receipt numbers are not must
 * 7. The vendor detail and place of expense is a must
*/
create table expenditure(
	id int primary key identity(1,1),
	date date not null check(date <= sysdatetime()),
	item varchar(64) not null check(item!='pirated'),
	amount decimal(8,2) check(amount > 0 and amount <= 1000),
	mode varchar(16) not null default 'cash' check(mode='cash' or mode='cheque' or mode='creditcard' or mode='debitcard'),
	instrument_no varchar(16),
	vendor varchar(32) not null,
	place varchar(32) not null,
	receipt_no varchar(32)
);

/*
 * Insert data with automatic primary key values
*/
insert into expenditure (date, item, amount, mode, instrument_no, vendor, place, receipt_no) 
values('07/23/2012', 'Coffee', 12, 'cash', null, 'Cafe', 'Bangalore', null);
insert into expenditure (date, item, amount, mode, instrument_no, vendor, place, receipt_no) 
values('07/23/2012', 'Coffee', 12, 'cash', null, 'Cafe', 'Bangalore', null);
insert into expenditure (date, item, amount, mode, instrument_no, vendor, place, receipt_no) 
values('07/23/2012', 'Coffee', 12, 'cash', null, 'Cafe', 'Bangalore', null);
/*
 *	Insert data with a specific value for ID. 
*/
set identity_insert expenditure on;
insert into expenditure (id, date, item, amount, mode, instrument_no, vendor, place, receipt_no) 
values(15, '07/23/2012', 'Coffee', 12, 'cash', null, 'Cafe', 'Bangalore', null);
set identity_insert expenditure off;

/*
 * Insert data with automatic primary key values
*/
insert into expenditure (date, item, amount, mode, instrument_no, vendor, place, receipt_no) 
values('07/23/2012', 'Coffee', 12, 'cash', null, 'Cafe', 'Bangalore', null);
insert into expenditure (date, item, amount, mode, instrument_no, vendor, place, receipt_no) 
values('07/23/2012', 'Coffee', 12, 'cash', null, 'Cafe', 'Bangalore', null);

/*
 ******************************************* FORIEGN KEYS ******************************
*/
if object_id('books', 'U') is not null
	drop table books;

if object_id('publishers', 'U') is not null
	drop table publishers;

create table contacts(
	id int primary key identity(1,1),
	address varchar(32) not null,
	phone bigint check(phone > 0)
);

create table publishers(
	id int primary key identity(1,1),
	name varchar(32) unique not null,
	contact_id int references contacts(id)
);

create table authors(
	id int primary key identity(1,1),
	name varchar(32) not null,
	contact_id int references contacts(id)
);

create table books(
	isbn int primary key, 
	title varchar(32) not null, 
	price decimal(6,2) default 0 check (price >= 0),
	pages int check (pages%4 = 0),
	type varchar(16) check (type in ('text', 'reference', 'magazine')),
	publisher_id int references publishers(id)
);

create table books_authors(
	book_isbn int references books(isbn),
	author_id int references authors(id)
);

insert into contacts(address, phone) values('New Delhi', 9876773648);
insert into contacts(address, phone) values('New Delhi', 9731428765);
insert into contacts(address, phone) values('New York', 1229876778);
insert into contacts(address, phone) values('Mumbai', 9872336771);
insert into publishers (name, contact_id) values ('TMH Publishers', 1); 
insert into publishers (name, contact_id) values ('Rupa & Co', 2);
insert into authors (name, contact_id) values('Codd', 3);
insert into authors (name, contact_id) values('Mrinal', 4); 
insert into books values(123434, 'SQL Handson', 500, 360, 'text', 1);
insert into books values(789877, 'I have a Dream', 150, 700, 'reference', 2);
insert into books_authors values(123434, 1);
insert into books_authors values(789877, 2);